==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/ASPECTPROMPTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ASPECTPROMPTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASPECTPROMPTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROMPTSEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASPECTPROMPTID_Type", propOrder = {
    "aspectid",
    "promptsequence",
    "description"
})
public class ASPECTPROMPTID_Type {

    @XmlElement(name = "ASPECTID", required = true)
    protected ASPECTID_Type aspectid;
    @XmlElement(name = "PROMPTSEQUENCE")
    protected long promptsequence;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété aspectid.
     * 
     * @return
     *     possible object is
     *     {@link ASPECTID_Type }
     *     
     */
    public ASPECTID_Type getASPECTID() {
        return aspectid;
    }

    /**
     * Définit la valeur de la propriété aspectid.
     * 
     * @param value
     *     allowed object is
     *     {@link ASPECTID_Type }
     *     
     */
    public void setASPECTID(ASPECTID_Type value) {
        this.aspectid = value;
    }

    /**
     * Obtient la valeur de la propriété promptsequence.
     * 
     */
    public long getPROMPTSEQUENCE() {
        return promptsequence;
    }

    /**
     * Définit la valeur de la propriété promptsequence.
     * 
     */
    public void setPROMPTSEQUENCE(long value) {
        this.promptsequence = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/ASPECTPROMPTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ASPECTPROMPTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASPECTPROMPTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROMPTSEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASPECTPROMPTID_Type", propOrder = {
    "aspectid",
    "promptsequence",
    "description"
})
public class ASPECTPROMPTID_Type {

    @XmlElement(name = "ASPECTID", required = true)
    protected ASPECTID_Type aspectid;
    @XmlElement(name = "PROMPTSEQUENCE")
    protected long promptsequence;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the aspectid property.
     * 
     * @return
     *     possible object is
     *     {@link ASPECTID_Type }
     *     
     */
    public ASPECTID_Type getASPECTID() {
        return aspectid;
    }

    /**
     * Sets the value of the aspectid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ASPECTID_Type }
     *     
     */
    public void setASPECTID(ASPECTID_Type value) {
        this.aspectid = value;
    }

    /**
     * Gets the value of the promptsequence property.
     * 
     */
    public long getPROMPTSEQUENCE() {
        return promptsequence;
    }

    /**
     * Sets the value of the promptsequence property.
     * 
     */
    public void setPROMPTSEQUENCE(long value) {
        this.promptsequence = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
